@@ -14,14 +14,14 @@ log = logging.getLogger( __name__ )
 
 _python3 = sys.version_info[0]>=3
 
-def monkeyPatch( ):
-    if getattr( monkeyPatch,'_isMonkeyPatched',False):
-        return
+def monkeyPatch():
     """
     Patches Kanone so that any validation returns a Deferred, thus
     one can write asynchronous validators using Twisted's non-blocking API.
     Schema and ForEach fields are validated concurrently.
     """
+    if getattr( monkeyPatch,'_isMonkeyPatched',False):
+        return
 
     from ..lib import Context, PASS, MISSING
 
@@ -334,6 +334,7 @@ def monkeyPatch( ):
 
             d.errback( Invalid( value, self, matchType=self.type, criteria=result.value ) )
         else:
+            val = value
             if self.ignoreCase:
                 result = str(result).lower()
                 val = str(value).lower()
@@ -349,8 +350,6 @@ def monkeyPatch( ):
             if not self.required.match(value):
                 raise Invalid( value, self, matchType=self.type, criteria=self.required.pattern)
             return value
-        elif self.type is Match.RAW:
-            compare = self.required
         elif self.type is Match.VALIDATOR:
             compare = defer.maybeDeferred\
                 ( self.required.validate
@@ -361,6 +360,8 @@ def monkeyPatch( ):
             d = defer.Deferred()
             compare.addBoth( match_gotResult, self, value, d )
             return d
+        else:
+            compare = self.required
 
         val = value
         if self.ignoreCase:
@@ -425,7 +426,7 @@ def monkeyPatch( ):
         else:
             d.errback( errors.pop(0) )
 
-    def schema__createContextChilds_on_value_done( waste, d, schema, value, result, errors ):
+    def schema__createContextChildren_on_value_done( waste, d, schema, value, result, errors ):
         if not errors:
             d.callback( result )
         else:
@@ -494,7 +495,7 @@ def monkeyPatch( ):
 
         return d
 
-    def schema__createContextChilds_on_value( self, context, value ):
+    def schema__createContextChildren_on_value( self, context, value ):
         isList = isinstance(value, list) or isinstance(value,tuple) or isinstance(value,set)
 
         if not isList and not isinstance( value, dict ):
@@ -560,7 +561,7 @@ def monkeyPatch( ):
         d = defer.Deferred()
         jobs = defer.DeferredList( jobs )
         jobs.addCallback\
-            ( schema__createContextChilds_on_value_done
+            ( schema__createContextChildren_on_value_done
             , d
             , self
             , value
@@ -640,7 +641,7 @@ def monkeyPatch( ):
         return d
 
 
-    def forEach__createContextChilds_on_value( self, context, value ):
+    def forEach__createContextChildren_on_value( self, context, value ):
         isList = isinstance( value, list) or isinstance(value, tuple) or isinstance(value, set)
 
         if not isList:
@@ -654,7 +655,7 @@ def monkeyPatch( ):
         errors = []
 
         # populate
-        childs = []
+        children = []
         if isList or self.numericKeys:
             context.setIndexFunc( lambda index: str(index) )
 
@@ -671,7 +672,7 @@ def monkeyPatch( ):
                 contextChild = context( str( pos ) )
                 contextChild.validator = self.validator
                 contextChild.__value__ = val
-                childs.append( contextChild )
+                children.append( contextChild )
 
         else:
             context.setIndexFunc( None )
@@ -682,11 +683,11 @@ def monkeyPatch( ):
                 contextChild = context( key )
                 contextChild.validator = self.validator
                 contextChild.__value__ = val
-                childs.append( contextChild )
+                children.append( contextChild )
 
         jobs = []
         #validate
-        for childContext in childs:
+        for childContext in children:
             jobs.append\
                 ( childContext.validate()\
                     .addCallback\
@@ -706,7 +707,7 @@ def monkeyPatch( ):
         d = defer.Deferred()
         jobs = defer.DeferredList( jobs )
         jobs.addCallback\
-            ( schema__createContextChilds_on_value_done
+            ( schema__createContextChildren_on_value_done
             , d
             , self
             , value
@@ -722,8 +723,6 @@ def monkeyPatch( ):
     def field_validate(self, context, value):
         fieldcontext = self.getField( context, self.path )
 
-        result = PASS
-
         if not self.useResult:
             result = fieldcontext.value
 
@@ -798,9 +797,9 @@ def monkeyPatch( ):
     Match.on_value = match_on_value
     If.validate = if_validate
     Schema._on_value = schema__on_value
-    Schema._createContextChilds_on_value = schema__createContextChilds_on_value
+    Schema._createContextChildren_on_value = schema__createContextChildren_on_value
     ForEach._on_value = forEach__on_value
-    ForEach._createContextChilds_on_value = forEach__createContextChilds_on_value
+    ForEach._createContextChildren_on_value = forEach__createContextChildren_on_value
     Field.validate = field_validate
     MXLookup.on_value = mxLookup_on_value
 
